Module: Processing::Proxy
- Includes:
- Math
- Defined in:
- lib/ruby-processing/app.rb
Overview
This module will get automatically mixed in to any inner class of a Processing::App, in order to mimic Java’s inner classes, which have unfettered access to the methods defined in the surrounding class.
Class Method Summary collapse
-
.desired_method_names(inner_class) ⇒ Object
Generate the list of method names that we’d like to proxy for inner classes.
-
.included(inner_class) ⇒ Object
Don’t do all of the work unless we have an inner class that needs it.
-
.proxy_constants(inner_class) ⇒ Object
Proxy the sketch’s constants on to the inner classes.
-
.proxy_methods(inner_class) ⇒ Object
Proxy methods through to the sketch.
Class Method Details
.desired_method_names(inner_class) ⇒ Object
Generate the list of method names that we’d like to proxy for inner classes. Nothing camelCased, nothing __internal__, just the Processing API.
262 263 264 265 266 267 268 |
# File 'lib/ruby-processing/app.rb', line 262 def self.desired_method_names(inner_class) bad_method = /__/ # Internal JRuby methods. unwanted = PApplet.superclass.instance_methods + Object.instance_methods unwanted -= ['width', 'height', 'cursor', 'create_image', 'background', 'size', 'resize'] methods = Processing::App.public_instance_methods methods.reject {|m| unwanted.include?(m) || bad_method.match(m) || inner_class.method_defined?(m) } end |
.included(inner_class) ⇒ Object
Don’t do all of the work unless we have an inner class that needs it.
298 299 300 301 |
# File 'lib/ruby-processing/app.rb', line 298 def self.included(inner_class) proxy_methods(inner_class) proxy_constants(inner_class) end |
.proxy_constants(inner_class) ⇒ Object
Proxy the sketch’s constants on to the inner classes.
289 290 291 292 293 294 |
# File 'lib/ruby-processing/app.rb', line 289 def self.proxy_constants(inner_class) Processing::App.constants.each do |name| next if inner_class.const_defined?(name) inner_class.const_set(name, Processing::App.const_get(name)) end end |
.proxy_methods(inner_class) ⇒ Object
Proxy methods through to the sketch.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/ruby-processing/app.rb', line 272 def self.proxy_methods(inner_class) code = desired_method_names(inner_class).inject('') do |code, method| code << <<-EOS def #{method}(*args, &block) # def rect(*args, &block) if block_given? # if block_given? $app.send :'#{method}', *args, &block # $app.send(:rect, *args, &block) else # else $app.#{method} *args # $app.rect *args end # end end # end EOS end inner_class.class_eval(code) end |